<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation type="unfinished">Fout in config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="unfinished">Fout bij het uitvoeren van plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="unfinished">Kon bestand niet laden.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="unfinished">Ongeldig bestandsformaat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="unfinished">Kon bestand niet opslaan.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="unfinished">Kon XML niet parsen:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="unfinished">Onbekende encodering.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="unfinished">Antwoord ontbreekt op regel:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="unfinished">Kon gegevensbank niet laden.
Ik creëer tmp bestand.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="unfinished">Bestand bestaat:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="unfinished">&amp;Overschrijven</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="unfinished">Duplicaten verwijderd: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="unfinished">Er zijn kaarten met andere antwoord voor vraag:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished">&amp;Samenvoegen en bewerken</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="unfinished">&amp;Niet samenvoegen</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="unfinished">Klaar!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Je kent deze kaart nog niet.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Als &apos;0&apos;, maar het wordt iets duidelijker.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"> Toon het minder vaak.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Je hebt deze kaart nu onthouden,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> en zult het waarschijnlijk blijven onthouden voor een aantal dagen.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Deze kaart ben je volledig vergeten.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Nauwelijks correct antwoord. Het tijdsinterval was veel te lang.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Correct antwoord, maar met enige moeite.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> Het interval was waarschijnlijk te lang.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Correct antwoord, met enige moeite.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished"> Het tijdsinterval was vermoedelijk precies juist.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Correct antwoord, maar zonder enige</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> moeite. Het interval was waarschijnlijk te kort.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Hoofd programmeur: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Voor meer informatie: http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Activeer categorieën</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Selecteer de te activeren categorieën:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Activeer geen</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Activeer alle</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleer</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Huidige kaart opgeven?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nee</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwoord:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Geschreven vorm:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Vertaling:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Kaart is reeds in de gegevensbank aanwezig.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Duplikaat niet toegevoegd.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Er zijn verschillende antwoorden voor</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> deze vraag:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Samenvoegen en bewerken</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Toevoegen in deze vorm</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Niet toevoegen</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Kaarten toevoegen</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Uitspraak:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwoord:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Voeg &amp;omgekeerd toe</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Kies eerste beoordeling:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Je kunt het antwoord niet onthouden of je bent het vergeten.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Als &apos;1&apos;, maar de kaart wordt enigszins bekender.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Je hebt de kaart onthouden en zult het waarschijnlijk voor enkele dagen blijven onthouden.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Juiste antwoord, maar met behoorlijke moeite. De tijdsspanne was waarschijnlijk te groot</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Juiste antwoord, met enige moeite. De tijdsspanne was waarschijnlijk precies goed.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Juiste antwoord, maar zonder enige problemen. Het tijdsinterval was waarschijnlijk te kort.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Geef vraag en antwoord en kies een eerste beoordeling.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Voorvertoning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Verander categorie</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne configuratie</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Sta met de muiscursor enige tijd stil over de knoppen, om meer informatie te krijgen.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Stel Vraag en Antwoord lettertype in</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Stel het lettertype in voor het weergeven van losse vragen en antwoorden</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Stel het lettertype van de lijst in</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Stel het lettertype in voor het weergeven van een lijst van alle kaarten</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Vergroot de non-latin letters met</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Soms zijn complexe symbolen moeilijk te lezen in de standaard lettertypegrootte</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>punt(en)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Log uploaden</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Uploaden van anonieme logbestanden</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Deel anonieme statistieken om mee te helpen aan geheugenonderzoek</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Behandeling duplicaten</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Controleer op duplicaten bij het toevoegen van nieuwe kaarten</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Sta duplicaten toe in verschillende categorieën</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Herhalingsproces</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">Aantal 0 beoordelingskaarten in eenmaal te leren:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Let op: dit in NIET het aantal kaarten met beoordeling 0 welke je *per dag* wil leren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleer</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Bewerk kaart</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwoord:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+0</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Voorvertoning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleer</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+A</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Een moment...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerk</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Voorvertoning</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Voeg omgekeerd toe</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>&amp;Statistieken</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijder</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>Ve&amp;rander categorie</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Voeg &amp;omgekeerd toe</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Voeg omkeerde vraagstelling toe voor deze kaarten?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Voeg omkeerde vraagstelling toe voor deze kaart?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Dit zou duplicaten kunnen toevoegen als de omgekeerde </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>kaarten al aanwezig zijn. 
dus wellicht wilt u </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>&apos;verwijderen duplicaten&apos; uitvoeren na afloop.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nee</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Beoordeling:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Eenvoud:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Herhalingen:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Uitvoeringen:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Aantal dagen vanaf laatste bevraging:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dagen tot volgende bevraging:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Verwijder deze kaarten?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Verwijder deze kaart?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>De ingevoerde tekst werd niet gevonden.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Zoek opnieuw</translation>
    </message>
    <message>
        <source>F</source>
        <translation>Z</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoek</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Antwoord</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Bewerk kaartenbak</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoek</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Klik rechts om een kaart te bewerken.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle bestanden (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteer</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Exporteer naar bestand</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Bestandsformaat:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Bestand om naar te exporteren:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Blader</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Te exporteren categorieën:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Selecteer alles</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Verwijder leergegevens tijdens export</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleer</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle bestanden (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeer</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Importeer uit bestand</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Bestandsformaat:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Importeer uit bestand:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Blader</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Stop categorieloze kaarten in deze categorie:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Let op: alle kaarten zullen aan de huidige gegevensbank toegevoerd worden.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Verwijder leergegevens tijdens import</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleer</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Mnemosyne gegevensbanken (*.mem)</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Een moment...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>Verwijder huidige kaart?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nee</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Komt over </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation>dag(en) terug.</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Volgende bevraging: vandaag.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Volgende bevraging: morgen.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Volgende bevraging over </translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standaard&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Toon &amp;antwoord</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Leer vooruit op schema</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Aantal dagen tot volgende bevraging:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Beoordeel uw antwoord:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Geroosterd: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>Niet onthouden: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Alle: </translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> dagen.</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Toon anwoord</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Anwoord:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Toon anwoord</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Beoordeel jouw antwoord:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Open...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Bewaar</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Bewaar &amp;Als...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;fsluiten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Voeg kaarten toe</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Voeg kaarten toe</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Act&amp;ivate categories</source>
        <translation type="obsolete">Act&amp;iveer categorieën</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Bewerk kaartenbak</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Bewerk &amp;kaartenbak</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importeer</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporteer</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Toon &amp;toolbar</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Bewerk deze kaart</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>Bewerk &amp;deze kaart</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Verwijder deze kaart</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>Ver&amp;wijder deze kaart</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Verw</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>Verwijder d&amp;uplicaten</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Configureer Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Eerste stappen</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>Eerste s&amp;tappen</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Onder, Onder</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space
</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Toon statistieken</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Toon stat&amp;istieken</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Tip van de dag</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Tip van de dag</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Hoofd toolbar (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Kaartenbak</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Act&amp;iveer categorieën</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Voorvertoning kaart</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Vraag:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwoord:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Eerste stappen</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Goedendag!
Ik ben Mnemosyne, een vlinder vernoemd naar de Griekse godin van het geheugen. 

De antwoorden die je vaker vergeet stel ik je vaker en antwoorden op vragen die je goed kent laat ik je verder geen tijd op verliezen door ze te vaak te vragen. Daardoor wordt het voor jij meer efficient om de antwoorden op vragen te onthouden.

Om dat goed te kunnen doen, vraag ik je om een beoordeling te geven van het antwoord dat je geeft op iedere vraag.

Laten we eens kijken naar deze beoordelingen.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Introductie</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Beoordelingen van 0 tot 5.

De &apos;0&apos; en &apos;1&apos; beoordelingen worden gebruikt als je het antwoord nog niet kent of dat je het opnieuw vergeten bent. Een kaart met beoordeling &apos;1&apos; wordt al enigszins meer bekend dan een &apos;0&apos; en zal minder vaak herhaald worden.

Ik zal deze vragen blijven stellen totdat je ze een beoordeling &apos;2&apos; of hoger geeft (het maakt niet uit welke preciese beoordeling). Beoordeling &apos;2&apos; betekend dat je denkt de kaart op z&apos;n minst 2 dagen kunnen onthouden. Het geeft de transitie van korte- naar langetermijn geheugen aan.

Hierna zal ik de kaart ergens in de toekomst roosteren, op een moment dat ik denk dat je hem onthouden zou moeten hebben met enige moeite, zonder dat je het volledig vergeten bent. Dit is het meest efficient voor het leerproces.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Beoordelingen 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Als ik je een bepaalde vraag te snel stel en je kunt het beantwoorden zonder enige moeie, geef het dan een &apos;5&apos; als beoordeling. Dit neem ik mee voor de volgende keer door een stuk langer te wachten voordat ik je de vraag opnieuw stel.

Als ik het precies goed doe, zodanig dat je het met enige moeite kunt onthouden, gebruik dan een &apos;4&apos; als beoordeling.

Kost het echter bijzonder veel moeite om het juiste antwoord bij de vraag te vinden en denk je dat ik te lang heb gewacht met het stellen van deze vraag, beooldeel het dan met een &apos;3&apos;.

Ben je het helemaal vergeten, geef het dan een &apos;0&apos; of een &apos;1&apos; en ik zal je de vraag stellen totdat je denkt het te kunnen onthouden gedurende een aantal dagen.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Beoordelingen 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Houdt je van statistiek? Ik kan een gedetaileerd log bijhouden van jouw revisies.

Daarnaast kan ik, mocht je dat willen, een anoniem log sturen naar een centrale locatie ter analyse, zodat jij kunt helpen mij beter te maken. Op deze manier kun je ook je steentje bijdragen aan lange-termijn geheugenonderzoek.

Klik het volgende aankruisvak aan, mocht je dit willen.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Verstuur een anonieme log</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Je kunt dit later altijd veranderen in het &apos;Configureer Mnemosyne&apos; dialoog)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see &lt;a href =&quot;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://www.mnemosyne-proj.sourceforge.net&lt;/a&gt;
&lt;p&gt;
Happy learning!</source>
        <translation type="obsolete">Je bent nu klaar voor de start!
&lt;p&gt;
Voeg nieuwe kaarten toe door op het &apos;plus&apos; icoon te klikken, linksbovenaan.
&lt;p&gt;
Je hoeft je niet druk te maken om alles steeds op te slaan, ik zal dat automatisch doen.
&lt;p&gt;
De beste resultaten krijg je als je iedere dag een aantal keer door de geroosterde vragen loopt, alhoewel ik ook mijn best doe als je besluit dit uit te stellen, of vooruit wilt lopen op de vragen.

Voor meer documentatie, bekijk &lt;a href=&apos;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://mnemosyne-proj.sourceforge.net&quot;&lt;/a&gt;
&lt;p&gt;
Veel plezier met leren!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Klaar om te starten</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation type="unfinished">Je bent nu klaar voor de start!
&lt;p&gt;
Voeg nieuwe kaarten toe door op het &apos;plus&apos; icoon te klikken, links bovenaan.
&lt;p&gt;
Je hoeft je niet druk te maken om alles steeds op te slaan, ik zal dat automatisch doen.
&lt;p&gt;
De beste resultaten krijg je als je iedere dag een aantal keer door de geroosterde vragen loopt, alhoewel ik ook mijn best doe als je besluit dit uit te stellen, of vooruit wilt lopen op de vragen.

Voor meer documentatie, bekijk http://mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Veel plezier met leren!</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Voeg &amp;afbeelding toe</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+a</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Voeg &amp;geluid toe</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+g</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3-kants invoer</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Voeg afbeelding toe</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Geluidsbestanden</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Voeg geluid toe</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>Geroosterde kaarten voor de volgende dagen:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>dag(en):</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Aantal kaarten met de volgende beoordeling:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Beoordeling</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">Beoordeling:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">Eenvoud:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">Herhalingen:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">Uitvoeringen:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">Aantal dagen vanaf laatste bevraging:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">Dagen tot volgende bevraging:</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Kaarten</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Rooster</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Beoordelingen</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorieën</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>De beste resultaten behaal je als je iedere dag door de geroosterde kaarten gaat.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Als je een aantal dagen weggeweest bent, maak je dan niet te druk. Beantwoord zoveel vragen als je zelf denkt dat goed is om weer in schema te komen, de rest van de kaarten worden automatisch heringedeeld in het rooster.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>De &apos;Aantal 0 beoordelingskaarten in eenmaal te leren:&apos; instelling bepaald hoeveel nieuwe kaarten je in eenmaal probeert te leren. Het stelt echter &lt;b&gt;niet&lt;/b&gt; het aantal nieuw te leren kaarten per dag in. Jij bepaald zelf hoeveel nieuwe kaarten je wilt leren per dag, aan de hand van hoe jij je erover voelt.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Samenvattend, probeer iedere dag de geroosterde kaarten te doen, maar maak je niet al te druk om de &apos;geroosterd&apos; teller op nul te krijgen, en al helemaal niet om de &apos;niet onthouden&apos; teller op nul te krijgen.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Beoordeling &apos;1&apos; kaarten verschillen van beoordeling &apos;0&apos; kaarten omdat ze minder vaak bevraagd worden en omdat ze niet meedoen aan het &apos;aantal beoordeling &apos;0&apos; kaarten te leren in eenmaal&apos; instelling.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Je kunt toetsenbord-snelkoppelingen gebruiken om het je makkelijker te maken. Enter, Return of spatie geeft de standaard actie (&apos;Toon antwoord&apos; of &apos;beoordeling 4&apos;). De nummertoetsen kunnen gebruikt worden voor de beoordeling.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Door naar &apos;Activeer categorieën&apos; te gaan in het menu, kun je specifieke categorieëen selecteren die je beter wil bestuderen.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Het is aan te raden om alle kaarten in één grote gegevensbank te plaatsen en categorieën te gebruiken om ze te organiseren. Gebruik van &apos;Activeer categorieën&apos; is een stuk handiger dan het laden en opslaan van verschillende gegevensbanken.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Je kunt kaarten importeren uit een boel verschillende formaten: tab gescheiden tekstbestanden, Supermemo bestanden, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Als je je kaarten in Word of Excel hebt staan, exporteer ze dan tab gescheiden met UTF-8 unicode encoding, zodat je ze kunt importeren in Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Als je je kaarten wilt uitprinten, sla ze dan op als een txt bestand en open ze met je favoriete document processor (Word/OpenOffice).</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Je kunt kaarten met iemand delen door ze te exporteren als XML en de optie &apos;Verwijder leergegevens tijdens export&apos; te kiezen.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Als je vreemde talen leert met een ander schrift, dan is de standaard lettertypegrootte soms enigszins te klein. Als je deze karakters groter wilt weergeven, maar normale engelse tekst hetzelfde wilt houden, gebruik dan de &quot;vergroot non-latin letters met X punten&quot; optie.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Je kunt ook afbeeldingen en geluiden toevoegen aan je kaarten. Klik rechts in het vraag of antwoordveld als je een kaart aan het bewerken bent, en een pop-up menu verschijnt welke je de mogelijkheid geeft deze onderdelen toe te voegen.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>We raden aan om geluid en beeldbestanden in je .mnemosyne map op te slaan. Daardoor is het eenvoudiger je gegevens te versturen of te delen tussen verschillende computers.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Als je een drie-zijdige kaart toevoegd, zullen er twee normale kaarten worden aangemaakt. Eén met de vraag in geschreven vorm en als antwoord de uitspraak en vertaling, een andere met de vraag vertaald en het antwoord in geschreven vorm en de uitspraak.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Je kunt standaard HTML tags gebruiken in je kaarten om de presentatie te veranderen.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne kan LaTeX gebruiken om mathematische formulen weer te geven, bijv. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (Hiervoor moeten LaTeX en dvipng geïnstalleerd zijn.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Voor een backup van je gegevens kun je het beste je .mnemosyne directory kopieëren (mits je al je bestanden daar opslaat) naar een andere schijf. Mnemosyne slaat automatisch XML-gebasseerde backups op in .mnemosyne/backups, maar dat helpt niets als je schijf het begeeft... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Je kunt Mnemosyne draaien vanaf een USB sleuten. Kopieer C:\Program Files\Mnemosyne naar je USB sleutel en kopieer daarna de .mnemosyne map naar de Mnemosyne map op de USB sleutel.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Als je Mnemosyne gebruikt op meerdere computers, dan is er een handig tooltje genaamd Unison dat je kan helpen om je gegevens gesynchroniseerd te houden. Bekijk de Mnemosyne website voor meer gegevens.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Je kunt de kaarten in het &apos;Bewerk kaartenbak&apos; dialoog sorteren op antwoord of categorie door te klikken op de desbetreffende kolomtitel. Nogmaals klikken op de titel draait de sortering om.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Als je meer gedetaileerde controle wilt hebben over LaTeX, zie dan de uitleg over de &lt;$$&gt;...&lt;/$$&gt; en &lt;latex&gt;...&lt;/latex&gt; tags op de Mnemosyne website.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Gevorderde gebruikers kunnen Mnemosyne verder aanpassen door de config.py bestand in hun .mnemosyne map aan te passen. Ze kunnen ook plugins installeren om Mnemosyne nog dieper aan te passen.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Tip van de dag</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wist je dat...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Toon tips bij het starten</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+T</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Vorige</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>V&amp;olgende</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+S</translation>
    </message>
</context>
<context>
    <name>qApp</name>
    <message>
        <source>Error in config.py:</source>
        <translation type="obsolete">Fout in config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="obsolete">Fout bij het uitvoeren van plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="obsolete">Kon bestand niet laden.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="obsolete">Ongeldig bestandsformaat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="obsolete">Kon bestand niet opslaan.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="obsolete">Kon XML niet parsen:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="obsolete">Onbekende encodering.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="obsolete">Antwoord ontbreekt op regel:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="obsolete">Kon gegevensbank niet laden.
Ik creëer tmp bestand.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="obsolete">Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="obsolete">Bestand bestaat:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="obsolete">&amp;Overschrijven</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuleer</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="obsolete">Duplicaten verwijderd: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="obsolete">Er zijn kaarten met andere antwoord voor vraag:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="obsolete">&amp;Samenvoegen en bewerken</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="obsolete">&amp;Niet samenvoegen</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="obsolete">Klaar!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="obsolete">Je kent deze kaart nog niet.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="obsolete">Als &apos;0&apos;, maar het wordt iets duidelijker.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="obsolete"> Toon het minder vaak.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="obsolete">Je hebt deze kaart nu onthouden,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="obsolete"> en zult het waarschijnlijk blijven onthouden voor een aantal dagen.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="obsolete">Deze kaart ben je volledig vergeten.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="obsolete">Nauwelijks correct antwoord. Het tijdsinterval was veel te lang.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="obsolete">Correct antwoord, maar met enige moeite.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="obsolete"> Het interval was waarschijnlijk te lang.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="obsolete">Correct antwoord, met enige moeite.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="obsolete"> Het tijdsinterval was vermoedelijk precies juist.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="obsolete">Correct antwoord, maar zonder enige</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="obsolete"> moeite. Het interval was waarschijnlijk te kort.</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="obsolete"> dagen.</translation>
    </message>
</context>
</TS>
